@@ -1910,7 +1910,7 @@ c       x = The solution of  R x = b .
 c--------------------------------------------------------------------
 c     Reinhard Furrer June 2008, April 2012
 
-      if (r(ir(k+1)-1) .eq. 0.0 ) goto 5
+      if (r(ir(n+1)-1) .eq. 0.0 ) goto 5
       do l=1,p
          x(n,l) = b(n,l) / r(ir(n+1)-1)
          do 3 k = n-1,1,-1
